Exception: Rbxl::SheetNotFoundError
- Defined in:
- lib/rbxl/errors.rb
Overview
Raised by ReadOnlyWorkbook#sheet when the requested sheet name is not present in the workbook.
Raised by ReadOnlyWorkbook#sheet when the requested sheet name is not present in the workbook.